@@ -44,6 +44,10 @@ class CloudnsServerError(CloudnsRuntimeError):
     pass
 
 
+class CloudnsAuthenticationFailure(CloudnsRuntimeError):
+    pass
+
+
 class RecordNotFound(CloudnsRuntimeError):
     pass
 
@@ -62,3 +66,24 @@ class RecordNotReady(CloudnsRuntimeError):
 
     """
     pass
+
+
+class ErrorNumbers(object):
+    """Error Numbers as defined in upstream api.
+
+    """
+    NOERROR = 0
+    API_IS_NOT_SUPPORTED = 1
+    HTTP_METHOD_IS_NOT_SUPPORTED = 2
+    AUTHENTICATE_FAILED = 3
+    PARA_IS_REQUIRED = 4    # missing required parameter
+    PARA_IS_INVALID = 5     # parameter syntax error
+    PERMISSION_DENIED = 6
+    DUPLICATE_USER = 7
+    DUPLICATE_ZONE = 8
+    PROCESS_FAILED = 9
+    UNEXPECT_RESULT = 10
+    USER_IS_INVALID = 11
+    ZONE_IS_INVALID = 12
+    REMOTE_VALIDATE_FAILED = 13   # parameter semantics error
+    UNCLASSIFY = 1000
