@@ -32,7 +32,7 @@ def join_by_comma_maybe(obj):
         result = obj
     else:
         try:
-            result = u','.join(obj)
+            result = u','.join([unicode(o) for o in obj])
         except TypeError as _:
             raise CloudnsBadUsage(u'join by comma failed: %s' % (obj,))
     return result
@@ -370,7 +370,7 @@ class User(object):
                 else:
                     raise
 
-    def delete_records(self, rids):
+    def delete_records(self, zone, rids):
         """delete records matching given rids.
 
         This differs from delete_record because it sends a single request to
@@ -380,11 +380,12 @@ class User(object):
         RecordNotReady exception. This is how the cloudns API works.
 
         Args:
+            zone: zone name
             rids: an iterable of record ids or comma seperated ids.
 
         """
         rids = join_by_comma_maybe(rids)
-        return self._dnscall('bulk_rec_delete', rids=rids)
+        return self._dnscall('bulk_rec_delete', z=zone, rids=rids)
 
     def search_record(self, zone, keyword):
         """return records that is in given zone and matches given keyword.
